@@ -4,7 +4,7 @@ import os
 import subprocess
 import sys
 
-__version__ = '0.2'
+__version__ = '0.3'
 
 
 class EnvOptionParser(optparse.OptionParser):
@@ -40,7 +40,7 @@ class Envdir(object):
         for env_path in env_paths:
             with open(env_path, 'r') as env_file:
                 root, name = os.path.split(env_path)
-                value = env_file.readline().strip()
+                value = env_file.read().strip()
                 yield name, value
 
     def read(self, path=None):
@@ -81,8 +81,17 @@ class Envdir(object):
                                    shell=False,
                                    bufsize=0,
                                    close_fds=True)
-
-        if process.wait() != 0:
-            self.parser.exit(process.returncode, '')
+        try:
+            if process.wait() != 0:
+                self.parser.exit(process.returncode, '')
+        except KeyboardInterrupt:
+            self.parser.exit()
 
 envdir = Envdir()
+
+
+def main():
+    envdir.main(sys.argv[1:])
+
+if __name__ == '__main__':
+    main()
